summaryrefslogtreecommitdiff
path: root/svx/inc/sdr/contact
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-12-15 10:31:06 +0200
committerNoel Grandin <noel@peralex.com>2015-12-15 10:42:52 +0200
commit4463da0488099b52959544923407b15d73d3e172 (patch)
treec0fd9ada0bfdf2d3925fc1c94bac3782d332ef5a /svx/inc/sdr/contact
parent00ea9e5e4ef2f20353c881ec5844ed3862897239 (diff)
use vector as container for Primitive3DReference
rather than uno::Sequence, since we modify this container a lot and uno::Sequence is expensive to update Change-Id: Id5bc5171cbc4b90b243e6dda6d572f21b3bdf00d
Diffstat (limited to 'svx/inc/sdr/contact')
-rw-r--r--svx/inc/sdr/contact/viewcontactofe3dcube.hxx2
-rw-r--r--svx/inc/sdr/contact/viewcontactofe3dextrude.hxx2
-rw-r--r--svx/inc/sdr/contact/viewcontactofe3dlathe.hxx2
-rw-r--r--svx/inc/sdr/contact/viewcontactofe3dpolygon.hxx2
-rw-r--r--svx/inc/sdr/contact/viewcontactofe3dsphere.hxx2
-rw-r--r--svx/inc/sdr/contact/viewobjectcontactofe3d.hxx8
6 files changed, 9 insertions, 9 deletions
diff --git a/svx/inc/sdr/contact/viewcontactofe3dcube.hxx b/svx/inc/sdr/contact/viewcontactofe3dcube.hxx
index ab97e4896914..dd8df707286b 100644
--- a/svx/inc/sdr/contact/viewcontactofe3dcube.hxx
+++ b/svx/inc/sdr/contact/viewcontactofe3dcube.hxx
@@ -43,7 +43,7 @@ namespace sdr
protected:
// This method is responsible for creating the graphical visualisation data which is
// stored in the local primitive list. Default creates a yellow replacement rectangle.
- virtual drawinglayer::primitive3d::Primitive3DSequence createViewIndependentPrimitive3DSequence() const override;
+ virtual drawinglayer::primitive3d::Primitive3DContainer createViewIndependentPrimitive3DContainer() const override;
};
} // end of namespace contact
} // end of namespace sdr
diff --git a/svx/inc/sdr/contact/viewcontactofe3dextrude.hxx b/svx/inc/sdr/contact/viewcontactofe3dextrude.hxx
index 20a73ae946fa..f498200a2fa2 100644
--- a/svx/inc/sdr/contact/viewcontactofe3dextrude.hxx
+++ b/svx/inc/sdr/contact/viewcontactofe3dextrude.hxx
@@ -44,7 +44,7 @@ namespace sdr
protected:
// This method is responsible for creating the graphical visualisation data which is
// stored in the local primitive list. Default creates a yellow replacement rectangle.
- virtual drawinglayer::primitive3d::Primitive3DSequence createViewIndependentPrimitive3DSequence() const override;
+ virtual drawinglayer::primitive3d::Primitive3DContainer createViewIndependentPrimitive3DContainer() const override;
};
} // end of namespace contact
} // end of namespace sdr
diff --git a/svx/inc/sdr/contact/viewcontactofe3dlathe.hxx b/svx/inc/sdr/contact/viewcontactofe3dlathe.hxx
index cedaa2563d00..026ffcf9ac51 100644
--- a/svx/inc/sdr/contact/viewcontactofe3dlathe.hxx
+++ b/svx/inc/sdr/contact/viewcontactofe3dlathe.hxx
@@ -44,7 +44,7 @@ namespace sdr
protected:
// This method is responsible for creating the graphical visualisation data which is
// stored in the local primitive list. Default creates a yellow replacement rectangle.
- virtual drawinglayer::primitive3d::Primitive3DSequence createViewIndependentPrimitive3DSequence() const override;
+ virtual drawinglayer::primitive3d::Primitive3DContainer createViewIndependentPrimitive3DContainer() const override;
};
} // end of namespace contact
} // end of namespace sdr
diff --git a/svx/inc/sdr/contact/viewcontactofe3dpolygon.hxx b/svx/inc/sdr/contact/viewcontactofe3dpolygon.hxx
index 2544414ab665..cc25773f5197 100644
--- a/svx/inc/sdr/contact/viewcontactofe3dpolygon.hxx
+++ b/svx/inc/sdr/contact/viewcontactofe3dpolygon.hxx
@@ -43,7 +43,7 @@ namespace sdr
protected:
// This method is responsible for creating the graphical visualisation data which is
// stored in the local primitive list. Default creates a yellow replacement rectangle.
- virtual drawinglayer::primitive3d::Primitive3DSequence createViewIndependentPrimitive3DSequence() const override;
+ virtual drawinglayer::primitive3d::Primitive3DContainer createViewIndependentPrimitive3DContainer() const override;
};
} // end of namespace contact
} // end of namespace sdr
diff --git a/svx/inc/sdr/contact/viewcontactofe3dsphere.hxx b/svx/inc/sdr/contact/viewcontactofe3dsphere.hxx
index 1ea99d3f461e..f7ff01e70732 100644
--- a/svx/inc/sdr/contact/viewcontactofe3dsphere.hxx
+++ b/svx/inc/sdr/contact/viewcontactofe3dsphere.hxx
@@ -44,7 +44,7 @@ namespace sdr
protected:
// This method is responsible for creating the graphical visualisation data which is
// stored in the local primitive list. Default creates a yellow replacement rectangle.
- virtual drawinglayer::primitive3d::Primitive3DSequence createViewIndependentPrimitive3DSequence() const override;
+ virtual drawinglayer::primitive3d::Primitive3DContainer createViewIndependentPrimitive3DContainer() const override;
};
} // end of namespace contact
} // end of namespace sdr
diff --git a/svx/inc/sdr/contact/viewobjectcontactofe3d.hxx b/svx/inc/sdr/contact/viewobjectcontactofe3d.hxx
index b70ceb164835..aa58d2f19d59 100644
--- a/svx/inc/sdr/contact/viewobjectcontactofe3d.hxx
+++ b/svx/inc/sdr/contact/viewobjectcontactofe3d.hxx
@@ -37,14 +37,14 @@ namespace sdr
// Primitive3D sequence of the ViewContact. This contains all necessary information
// for the graphical visualisation and needs to be supported by all VCs which
// can be visualized.
- drawinglayer::primitive3d::Primitive3DSequence mxPrimitive3DSequence;
+ drawinglayer::primitive3d::Primitive3DContainer mxPrimitive3DContainer;
// This method is responsible for creating the graphical visualisation data which is
// stored/cached in the local primitive. Default gets view-independent Primitive3D
// from the ViewContact using ViewContact::getViewIndependentPrimitive3DSequence(), takes care of
// visibility and ghosted.
// This method will not handle included hierarchies and not check geometric visibility.
- drawinglayer::primitive3d::Primitive3DSequence createPrimitive3DSequence(const DisplayInfo& rDisplayInfo) const;
+ drawinglayer::primitive3d::Primitive3DContainer createPrimitive3DContainer(const DisplayInfo& rDisplayInfo) const;
// also override the 2d method to deliver a 2d object with embedd3d 3d and the 3d transformation which is able to
// answer the get2DRange question accordingly
@@ -57,7 +57,7 @@ namespace sdr
// access to the local primitive sequence. This will ensure that the list is
// current in comparing the local list content with a fresh created incarnation
// This method will not handle included hierarchies or visibility.
- drawinglayer::primitive3d::Primitive3DSequence getPrimitive3DSequence(const DisplayInfo& rDisplayInfo) const;
+ drawinglayer::primitive3d::Primitive3DContainer getPrimitive3DContainer(const DisplayInfo& rDisplayInfo) const;
};
} // end of namespace contact
} // end of namespace sdr
@@ -37,14 +37,14 @@ namespace sdr
// This method is responsible for creating the graphical visualisation data which is
// stored/cached in the local primitive. Default gets view-independent Primitive3D
- // from the ViewContact using ViewContact::getViewIndependentPrimitive3DSequence(), takes care of
+ // from the ViewContact using ViewContact::getViewIndependentPrimitive3DContainer(), takes care of
// visibility and ghosted.
// This method will not handle included hierarchies and not check geometric visibility.